# scikit-traveltime: traveltime calculation using the fast marching method for Python


```python
import traveltime
v = 3000*np.ones((3, 3))
t = traveltime(x,y,z,V,S,R)
```

---


### Documentation

### PyPI
* http://pypi.python.org/pypi/scikit-traveltime

### Requirements
* Numpy >= 1.0.2
* scikit-fmm >= 1

### Bugs, questions, patches, feature requests, discussion & cetera
* Open a GitHub pull request or a GitHub issue

### Installing
* Via pip: `pip install scikit-traveltime`

### Version History:
* 0.0.1: July 1st, 2017
  
Copyright 2017 Thomas Mejer Hansen

BSD-style license. See LICENSE.txt in the source directory.
